@@ -42,7 +42,7 @@ main (int argc, char *argv[])
   context = gjs_context_new_with_search_path ((char**) search_path);
 
   if (!gjs_context_define_string_array(context, "ARGV",
-                                       argc - 1, (const char**)argv + 1,
+                                       argc, (const char**)argv,
                                        &error))
     {
       g_critical ("Failed to define ARGV: %s", error->message);
