@@ -28,6 +28,7 @@ const Gtk = imports.gi.Gtk;
 const GtkChamplain = imports.gi.GtkChamplain;
 const Champlain = imports.gi.Champlain;
 const Geocode = imports.gi.GeocodeGlib;
+const GObject = imports.gi.GObject;
 
 const Lang = imports.lang;
 const Mainloop = imports.mainloop;
@@ -54,6 +55,26 @@ const MapMinZoom = 2;
 const MapView = new Lang.Class({
     Name: 'MapView',
     Extends: GtkChamplain.Embed,
+    Properties: {
+        'routeVisible': GObject.ParamSpec.boolean('routeVisible',
+                                                   'Route visible',
+                                                   'Visibility of route layers',
+                                                   GObject.ParamFlags.READABLE |
+                                                   GObject.ParamFlags.WRITABLE,
+                                                   false)
+    },
+
+    get routeVisible() {
+        return this._routeLayer.visible || this._instructionMarkerLayer.visible;
+    },
+
+    set routeVisible(value) {
+        let isValid = Application.routeService.query.isValid();
+
+        this._routeLayer.visible = value && isValid;
+        this._instructionMarkerLayer.visible = value && isValid;
+        this.notify('routeVisible');
+    },
 
     _init: function() {
         this.parent();
@@ -68,7 +89,7 @@ const MapView = new Lang.Class({
         Application.geoclue.connect("location-changed",
                                     this._updateUserLocation.bind(this));
 
-        this._connectRouteSignals(Application.routeService.route);
+        this._connectRouteSignals();
     },
 
     _initView: function() {
@@ -110,13 +131,19 @@ const MapView = new Lang.Class({
         this.view.add_layer(this._userLocationLayer);
     },
 
-    _connectRouteSignals: function(route) {
+    _connectRouteSignals: function() {
+        let route = Application.routeService.route;
+        let query = Application.routeService.query;
+
         route.connect('update', this.showRoute.bind(this, route));
         route.connect('reset', (function() {
             this._routeLayer.remove_all();
             this._instructionMarkerLayer.remove_all();
         }).bind(this));
 
+        query.connect('notify', (function() {
+                this.routeVisible = query.isValid();
+        }).bind(this));
     },
 
     setMapType: function(mapType) {
@@ -166,10 +193,13 @@ const MapView = new Lang.Class({
     },
 
     showTurnPoint: function(turnPoint) {
-        let instructionMarker = new TurnPointMarker.InstructionMarker({ turnPoint: turnPoint,
-                                                                        mapView: this });
-        this._instructionMarkerLayer.add_marker(instructionMarker);
-        instructionMarker.goToAndSelect(false);
+        if (this._turnPointMarker)
+            this._turnPointMarker.destroy();
+
+        this._turnPointMarker = new TurnPointMarker.TurnPointMarker({ turnPoint: turnPoint,
+                                                                      mapView: this });
+        this._instructionMarkerLayer.add_marker(this._turnPointMarker);
+        this._turnPointMarker.goToAndSelect(false);
     },
 
     showSearchResult: function(place) {
@@ -185,6 +215,7 @@ const MapView = new Lang.Class({
 
     showRoute: function(route) {
         this._routeLayer.remove_all();
+        this.routeVisible = true;
 
         route.path.forEach(this._routeLayer.add_node.bind(this._routeLayer));
 
