@@ -229,22 +229,8 @@ const InstructionRow = new Lang.Class({
                                                'direction-image',
                                                'instruction-label',
                                                'distance-label']);
-        ui.instructionLabel.label  = this.turnPoint.instruction;
-
-        switch(this.turnPoint.type) {
-        case Route.TurnPointType.START:
-            ui.directionImage.icon_name = 'maps-point-start-symbolic';
-            break;
-        case Route.TurnPointType.END:
-            ui.directionImage.icon_name = 'maps-point-end-symbolic';
-            break;
-        case Route.TurnPointType.VIA:
-            ui.directionImage.icon_name = 'maps-point-end-symbolic';
-            break;
-        default:
-            ui.directionImage.resource = this.turnPoint.iconResource;
-            break;
-        }
+        ui.instructionLabel.label = this.turnPoint.instruction;
+        ui.directionImage.icon_name = this.turnPoint.iconName;
 
         if (this.turnPoint.distance > 0)
             ui.distanceLabel.label = Utils.prettyDistance(this.turnPoint.distance);
